import argparse
import glob
import os
import shutil
import sys


def move():
    shutil.move(sys.argv[1], sys.argv[2])


def mkdir():
    parser = argparse.ArgumentParser("mkdir")
    parser.add_argument("-p", "--parents",  default=False, action='store_true', help=" no error if existing, make parent directories as needed")
    parser.add_argument("-v", "--verbose", default=False, action='store_true', help="explain what is being done")
    parser.add_argument('files', metavar='FILES', nargs='+', help='directories to create')
    args = parser.parse_args(sys.argv[1:])

    failed = False
    for file in args.files:
        try:
            if args.parents:
                os.makedirs(file)
            else:
                os.mkdir(file)
        except FileExistsError:
            print(f'mkdir: cannot create directory ‘{file}’: File exists')
            failed = True

    sys.exit(1 if failed else 0)


def which():
    shutil.which(sys.argv[1])


def rm():
    parser = argparse.ArgumentParser("rm")
    parser.add_argument("-f", "--force", default=False, action='store_true', help="ignore nonexistent files and arguments, never prompt")
    parser.add_argument("-r", "-R", "--recursive",  default=False, action='store_true', help="remove directories and their contents recursively")
    parser.add_argument("-v", "--verbose",  default=False, action='store_true', help="explain what is being done")
    parser.add_argument('files', metavar='FILES', nargs='+', help='Files to remove')
    args = parser.parse_args(sys.argv[1:])
    failed = False
    for pattern in args.files:
        for file in glob.glob(pattern, recursive=args.recursive):
            if not os.path.exists(file) and not args.force:
                print(f"rm: cannot remove '{file}': No such file or directory")
                failed = True
            elif os.path.exists(file):
                try:
                    if os.path.isdir(file):
                        if args.recursive:
                            shutil.rmtree(file)
                        else:
                            print(f"rm: skipping directory {file}")
                    else:
                        os.remove(file)
                except PermissionError:
                    print(f"rm: permission error deleting {file}")
                    failed = True
            else:
                if args.verbose:
                    print(f"rm: Skipping non-existent file {file}")
    sys.exit(1 if failed else 0)
